<?php
class si_authors_list extends WP_Widget {

    /** 
     * constructor 
    */
    function __construct() {
		parent::__construct(
			'si_authors_list',
			__( 'Simplified: Blog Authors', pc_espro ),
			array( 'description' => __( 'Display blog authors with gravatars and post count', pc_espro ), )
		);
    }
	
	/**
	 * Front-end display of widget.
	 *
	 * @see WP_Widget::widget()
	 *
	 * @param array $args     Widget arguments.
	 * @param array $instance Saved values from database.
	 */
    public function widget( $args, $instance ) {
        extract( $args );
		global $wpdb;
		
      	$title = apply_filters( 'widget_title', $instance['title'] );
		$number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 5;
		if ( ! $number )
			$number = 5;
		$gravatar = ! empty ( $instance['gravatar'] ) ? $instance['gravatar'] : '';
		$count = ! empty( $instance['count'] ) ? $instance['count'] : '';
		$order_by_post_count = $instance['order_by_post_count'];		
		
        echo $before_widget;
        
        if ( ! empty( $title ) ) {
			echo $before_title . $title . $after_title;
        }
								$authors = get_users( array(
									'who' => 'authors',
									'number' => $number,
 									'orderby' => $order_by_post_count ? 'post_count' : 'display_name',
 									'order' => $order_by_post_count ? 'DESC' : 'ASC'
 								) );		
		

			echo '<ul class="si-authors-widget si-widget">';
				foreach ( $authors as $author ) {
					$posts_count = count_user_posts( $author->ID );
						
					if ( ! empty( $posts_count ) && $posts_count >= 1 ) {
						$author_info = get_userdata( $author->ID );
						echo '<li>';
							if ( ! empty( $gravatar ) && $gravatar == 1 ) {
								echo '<div><a href="' . get_author_posts_url( $author->ID ) .'" title="View ' . $author_info->display_name . ' archive">';
									echo get_avatar( $author->ID, 70 );
								echo '</a></div>';
							}
							
							echo '<h3><a href="' . get_author_posts_url( $author->ID ) .'" title="View ' . $author_info->display_name . ' archive">';
								echo $author_info->display_name;
							
							echo '</a></h3>';
								
								if( $count ) {
									echo ' (' . $posts_count . ')';
								}
								
						echo '</li>';
					}
				}
			
			echo '</ul>';
		

		echo $after_widget;
    }
	
    /** 
     * @see WP_Widget::form 
    */
    public function form( $instance ) {

    	$title = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
		$number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
		$gravatar = isset( $instance['gravatar'] ) ? esc_attr( $instance['gravatar'] ) : '';
		$count = isset( $instance['count'] ) ? esc_attr( $instance['count']) : '';
		$order_by_post_count = esc_attr($instance['order_by_post_count']);

        ?>
		<p>
        	<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Widget title:', pc_espro ); ?></label> 
          	<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>" />
        </p>

		<p><label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number of authors to show:', pc_espro ); ?></label>
		<input id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="text" value="<?php echo $number; ?>" size="3" /></p>

		<p>
         	<input id="<?php echo $this->get_field_id( 'count' ); ?>" name="<?php echo $this->get_field_name( 'count' ); ?>" type="checkbox" value="1" <?php checked( '1', $count ); ?>/>
          	<label for="<?php echo $this->get_field_id( 'count' ); ?>"><?php _e( 'Display Post Count?', pc_espro ); ?></label> 
        </p>

		<p>
          	<input id="<?php echo $this->get_field_id( 'gravatar' ); ?>" name="<?php echo $this->get_field_name( 'gravatar' ); ?>" type="checkbox" value="1" <?php checked( '1', $gravatar ); ?>/>
          	<label for="<?php echo $this->get_field_id( 'gravatar' ); ?>"><?php _e( 'Display Author Gravatar?', pc_espro ); ?></label> 
        </p>

        <p>
           <input id="<?php echo $this->get_field_id('order_by_post_count'); ?>" name="<?php echo $this->get_field_name('order_by_post_count'); ?>" type="checkbox" value="1" <?php checked( '1', $order_by_post_count ); ?>/>
           <label for="<?php echo $this->get_field_id('order_by_post_count'); ?>"><?php _e('Order By Post Count?', pc_espro); ?></label>
     </p>

        <?php 
    }

	/** 
     * @see WP_Widget::update 
    */
    public function update( $new_instance, $old_instance ) {
    	
		$instance = $old_instance;
		$instance['title'] = isset( $new_instance['title'] ) ? strip_tags( $new_instance['title'] ) : '';
		$instance['number'] = (int) $new_instance['number'];
		$instance['gravatar'] = isset( $new_instance['gravatar'] ) ? strip_tags( $new_instance['gravatar'] ) : '';
		$instance['count'] = isset( $new_instance['count'] ) ? strip_tags( $new_instance['count'] ) : '';
		$instance['order_by_post_count'] = strip_tags($new_instance['order_by_post_count']);
				
		return $instance;
    }

} // class widget ends


//register widget
add_action( 'widgets_init', function(){
     register_widget( 'si_authors_list' );
});	

?>