<?php
class si_recent_posts_widget extends WP_Widget {

    /** 
     * constructor 
    */
	function __construct() {
		parent::__construct(
			'si_recent_posts_widget', // Base ID
			__('Simplified: Recent Posts', pc_espro), // Name
			array('description' => __( 'Display recent posts with images.', pc_espro ),) // Args
		);
	}
	/**
	 * Front-end display of widget.
	 * @see WP_Widget::widget()
	 */
	public function widget( $args, $instance ) {


		/** This filter is documented in wp-includes/default-widgets.php */
      	$title = apply_filters( 'widget_title', $instance['title'] );		
		$number = ( ! empty( $instance['number'] ) ) ? absint( $instance['number'] ) : 5;
		if ( ! $number )
			$number = 5;
		$show_img = isset( $instance['show_img'] ) ? $instance['show_img'] : true;
		$show_author = isset( $instance['show_author'] ) ? $instance['show_author'] : false;
		$show_date = isset( $instance['show_date'] ) ? $instance['show_date'] : false;

		/**
		 * Filter the arguments for the Recent Posts widget.
		 * @see WP_Query::get_posts()
		 * @param array $args An array of arguments used to retrieve the recent posts.
		 */
		$r = new WP_Query( apply_filters( 'widget_posts_args', array(
			'posts_per_page'      => $number,
			'no_found_rows'       => true,
			'post_status'         => 'publish',
			'ignore_sticky_posts' => true
		) ) );

		if ($r->have_posts()) :
?>
		<?php echo $args['before_widget']; ?>
		<?php if ( $title ) {
			echo $args['before_title'] . $title . $args['after_title'];
		} ?>
		<ul class="si-recent-widget si-widget">
		<?php while ( $r->have_posts() ) : $r->the_post(); ?>
			
<li>

<?php if ( $show_img ) : ?>
   <a href="<?php the_permalink(); ?>" title="<?php the_title_attribute(); ?>">
	<span class="wid-thumb">
		<?php if ( has_post_thumbnail() ) : ?>
            <?php the_post_thumbnail('pc_espro-list-thumb'); ?>
        <?php endif; ?>
	</span>
    </a>

<?php endif; ?>
        
		<h3><a href="<?php the_permalink(); ?>">
		<?php get_the_title() ? the_title() : the_ID(); ?>
        </a></h3>

<?php if ( $show_author ) : ?>
		<span class="s_auth"><?php the_author_posts_link(); ?></span>
<?php endif; ?>

<?php if ( $show_date ) : ?>
		<span class="s_date"><?php echo get_the_date(); ?></span>
<?php endif; ?>

</li>
            
		<?php endwhile; ?>
		</ul>
		<?php echo $args['after_widget']; ?>
<?php
		// Reset the global $the_post as this query will have stomped on it
		wp_reset_postdata();

		endif;

	}

    /** 
     * @see WP_Widget::form 
    */
	public function form( $instance ) {
		$title     = isset( $instance['title'] ) ? esc_attr( $instance['title'] ) : '';
		$number    = isset( $instance['number'] ) ? absint( $instance['number'] ) : 5;
		$show_img = isset( $instance['show_img'] ) ? (bool) $instance['show_img'] : true;
		$show_author = isset( $instance['show_author'] ) ? (bool) $instance['show_author'] : true;
		$show_date = isset( $instance['show_date'] ) ? (bool) $instance['show_date'] : false;

?>
		<p><label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title:', pc_espro ); ?></label>
		<input class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" type="text" value="<?php echo $title; ?>" /></p>

		<p><label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number of posts to show:', pc_espro ); ?></label>
		<input id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" type="text" value="<?php echo $number; ?>" size="3" /></p>

		<p><input class="checkbox" type="checkbox" <?php checked( $show_img ); ?> id="<?php echo $this->get_field_id( 'show_img' ); ?>" name="<?php echo $this->get_field_name( 'show_img' ); ?>" />
		<label for="<?php echo $this->get_field_id( 'show_img' ); ?>"><?php _e( 'Display post thumbnail?', pc_espro ); ?></label></p>

		<p><input class="checkbox" type="checkbox" <?php checked( $show_author ); ?> id="<?php echo $this->get_field_id( 'show_author' ); ?>" name="<?php echo $this->get_field_name( 'show_author' ); ?>" />
		<label for="<?php echo $this->get_field_id( 'show_author' ); ?>"><?php _e( 'Display post author?', pc_espro ); ?></label></p>

		<p><input class="checkbox" type="checkbox" <?php checked( $show_date ); ?> id="<?php echo $this->get_field_id( 'show_date' ); ?>" name="<?php echo $this->get_field_name( 'show_date' ); ?>" />
		<label for="<?php echo $this->get_field_id( 'show_date' ); ?>"><?php _e( 'Display post date?', pc_espro ); ?></label></p>

<?php
	
	}

	
	/** 
     * @see WP_Widget::update 
    */
	public function update( $new_instance, $old_instance ) {
		$instance = $old_instance;
		$instance['title'] = strip_tags($new_instance['title']);
		$instance['number'] = (int) $new_instance['number'];
		$instance['show_date'] = isset( $new_instance['show_date'] ) ? (bool) $new_instance['show_date'] : false;
		$instance['show_author'] = isset( $new_instance['show_author'] ) ? (bool) $new_instance['show_author'] : false;
		$instance['show_img'] = isset( $new_instance['show_img'] ) ? (bool) $new_instance['show_img'] : false;
		return $instance;

	}
	
} // class widget ends


//register widget
add_action( 'widgets_init', function(){
     register_widget( 'si_recent_posts_widget' );
});	

?>